API docs for “spamfighter.core.firewall.FirewallMessagePack”

# Class s.c.f.FirewallMessagePack(object):

Part of spamfighter.core.firewall View Source View In Hierarchy

Объект, оборачивающий в один параметр Deferred все данные, необходимые при обработке сообщения.

Instance Variables | message | сообщение (type: `ITaggedMessage` )
| domain | текущий домен (type: `IDomain` )

Method | __init__ | Конструктор.
Method | debug | Добавить в лог отладочное сообщение.
Method | getLog | Получить текущий собранный отладочный лог.

def __init__(self, message, domain): (source)
Конструктор.

def debug(self, message): (source)
Добавить в лог отладочное сообщение.

В процессе движения по firewall в отладочном режиме собирается лог сообщений, описывающий процесс прохождения отдельных действий.

Parameters | message | отладочное сообщение (type: `str` )

def getLog(self): (source)
Получить текущий собранный отладочный лог.

Returns | лог сообщений (type: `list(str)` )